@@ -205,14 +205,16 @@ fullscreen_callback (GtkAction * action)
     gtk_window_unfullscreen (GTK_WINDOW (app));
 }
 
-static void
+static gboolean
 window_state_callback (GtkWidget * widget, GdkEventWindowState * event)
 {
   if (!(event->changed_mask & GDK_WINDOW_STATE_FULLSCREEN))
-    return;
+    return FALSE;
 
   set_fullscreen_actions (event->new_window_state &
 			  GDK_WINDOW_STATE_FULLSCREEN);
+    
+  return FALSE;
 }
 
 static void
@@ -506,8 +508,9 @@ load_option_list (SCM options_list)
 }
 
 static void
-option_cb (GtkToggleAction * action, gint n)
+option_cb (GtkToggleAction * action, gpointer n_ptr)
 {
+  gint n = GPOINTER_TO_INT (n_ptr);
   SCM options_list;
   SCM entry;
   gboolean statec;
