@@ -232,6 +232,9 @@ class NumberBox (gtk.Widget):
     def key_press_cb (self, w, e):
         if self.read_only: return
         txt = gtk.gdk.keyval_name(e.keyval)
+        if type(txt) == type(None):
+            # Make sure we don't trigger on unplugging the A/C charger etc
+            return        
         txt = txt.replace('KP_', '')
         if self.get_text() == txt:
             # If there's no change, do nothing
@@ -1006,16 +1009,20 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
         virgin self and line two represents our game-in-progress.
         """
         self.blank_grid()
-        virgin,in_prog = game.split('\n')
+        if '\n' in game:
+            virgin,in_prog = game.split('\n')
+        else:
+            virgin = game; in_prog = ''
         group_size=int(math.sqrt(len(virgin.split())))
         self.change_grid(virgin,group_size=group_size)
         # This int() will break if we go to 16x16 grids...
-        values = [int(c) for c in in_prog.split()]
-        for row in range(group_size):
-            for col in range(group_size):
-                index = row * 9 + col
-                if values[index] and not self.grid._get_(col,row):
-                    self.add_value(col,row,values[index])
+        if in_prog:
+            values = [int(c) for c in in_prog.split()]
+            for row in range(group_size):
+                for col in range(group_size):
+                    index = row * 9 + col
+                    if values[index] and not self.grid._get_(col,row):
+                        self.add_value(col,row,values[index])
 
     @simple_debug
     def setup_grid (self, grid, group_size):
@@ -1063,16 +1070,7 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
             if self.grid.check_for_completeness():
                 self.emit('puzzle-finished')
         except sudoku.ConflictError, err:
-            conflicts=[self.grid.find_conflict(err.x,err.y,err.value,err.type)]
-            # We check for more than one conflict...  We count on the
-            # order conflicts are checked for in our initial script in
-            # sudoku.py -- ROW then COLUMN then BOX
-            if err.type==sudoku.TYPE_ROW:
-                if err.value in self.grid.cols[err.x]:
-                    conflicts.append(self.grid.find_conflict(err.x,err.y,err.value,sudoku.TYPE_COLUMN))
-            if err.type in [sudoku.TYPE_COLUMN,sudoku.TYPE_ROW]:
-                if err.value in self.grid.boxes[self.grid.box_by_coords[(err.x,err.y)]]:
-                    conflicts.append(self.grid.find_conflict(err.x,err.y,err.value,sudoku.TYPE_BOX))
+            conflicts=self.grid.find_conflicts(err.x,err.y,err.value)
             for conflict in conflicts:
                 widget.set_error_highlight(True)
                 self.__entries__[conflict].set_error_highlight(True)
@@ -1133,7 +1131,7 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
             del self.__error_pairs__[(x,y)]
             for coord in errors_removed:
                 # If we're not an error by some other pairing...
-                if not self.__error_pairs__.has_key((x,y)):
+                if not self.__error_pairs__.has_key(coord):
                     linked_entry = self.__entries__[coord]
                     linked_entry.set_error_highlight(False)
                     # Its possible this highlighted error was never
